/*
    Text maid
    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __TOOLBAR_H__
#define __TOOLBAR_H__


#include "tmaid.h"


typedef struct ToolBar_Tag
{
  gchar                   *name;
  gchar                  **xpm;
  GtkItemFactoryCallback   callback;
  gpointer                 user_data;
  GtkWidget               *item;
} ToolBar;


extern ToolBar toolbar_items[];


#endif
